pub struct BinanceFuturesOpenInterestHist {
pub instrument_id: InstrumentId,
pub period: String,
pub points: Vec<BinanceFuturesOpenInterestHistPoint>,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Binance Futures historical open interest batch.
For COIN-M requests, the current Binance adapter support is limited to perpetual instruments. Although Binance also exposes quarter-delivery contract types on the historical OI endpoint, the futures instrument parsing/symbology path in this adapter is still perpetual-only.
Fields
instrument_id: InstrumentIdThe instrument for this batch.
period: StringThe Binance period string used for the request (e.g. “5m”).
points: Vec<BinanceFuturesOpenInterestHistPoint>Ordered open interest history points returned by Binance.
ts_event: UnixNanosUNIX timestamp (nanoseconds) for the batch, represented by the final point.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the instance was initialized.
Implementations
Sourceimpl BinanceFuturesOpenInterestHist
impl BinanceFuturesOpenInterestHist
Sourcepub fn new(
instrument_id: InstrumentId,
period: String,
points: Vec<BinanceFuturesOpenInterestHistPoint>,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub fn new( instrument_id: InstrumentId, period: String, points: Vec<BinanceFuturesOpenInterestHistPoint>, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new BinanceFuturesOpenInterestHist instance.